# Promotion

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**commit_hash** | **str** | commit_hash of promoted repo | [optional]
**distro_hash** | **str** | distro_hash of promoted repo | [optional]
**extended_hash** | **str** | extended_hash of promoted repo | [optional]
**promote_name** | **str** | name used for the promotion | [optional]
**timestamp**   | **str** | promotion timestamp          | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


